@@ -8,6 +8,7 @@ from contextlib import suppress
 from typing import Union
 
 import requests
+from django.conf import settings
 from django.utils.http import urlencode
 from google.cloud import tasks_v2
 from google.protobuf import timestamp_pb2
@@ -20,7 +21,7 @@ class _HttpClient(abc.ABC):
     """Abstract HTTP client"""
 
     _client = None
-    _project = 'expressmoney'
+    _project = 'expressmoney' if settings.IS_PROD else 'expressmoney-dev-1'
 
     def __init__(self,
                  service: str = 'default',
